rasterio package
================

Subpackages
-----------

.. toctree::

   rasterio.rio

Submodules
----------

.. toctree::

   rasterio._base
   rasterio._crs
   rasterio._env
   rasterio._err
   rasterio._example
   rasterio._features
   rasterio._fill
   rasterio._io
   rasterio._warp
   rasterio.compat
   rasterio.control
   rasterio.coords
   rasterio.crs
   rasterio.drivers
   rasterio.dtypes
   rasterio.enums
   rasterio.env
   rasterio.errors
   rasterio.features
   rasterio.fill
   rasterio.io
   rasterio.mask
   rasterio.merge
   rasterio.path
   rasterio.plot
   rasterio.profiles
   rasterio.sample
   rasterio.shutil
   rasterio.tools
   rasterio.transform
   rasterio.vfs
   rasterio.vrt
   rasterio.warp
   rasterio.windows

Module contents
---------------

.. automodule:: rasterio
   :members:
   :undoc-members:
   :show-inheritance:
